@@ -3,16 +3,18 @@ import sys
 
 from idautils import Strings
 
+CACHED_STRINGS_ATTR = "_ida_strings"
+
 
 @functools.cache
 def strings():
     # Cache it somewhere else, to avoid build strings every time we reload our plugin
     main_module = sys.modules["__main__"]
-    if hasattr(main_module, "strings"):
-        return getattr(main_module, "strings")  # noqa: B009
+    if hasattr(main_module, CACHED_STRINGS_ATTR):
+        return getattr(main_module, CACHED_STRINGS_ATTR)
 
     strings_obj = Strings()
-    setattr(main_module, "strings", strings_obj)  # noqa: B010
+    setattr(main_module, CACHED_STRINGS_ATTR, strings_obj)
     return strings_obj
 
 
